Class ObjectGraphNode
java.lang.Object
io.ebean.bean.ObjectGraphNode
- All Implemented Interfaces:
Serializable
Identifies a unique node of an object graph.
It represents a location relative to the root of an object graph and specific to a query and call stack hash.
- See Also:
-
Constructor Summary
ConstructorsConstructorDescriptionObjectGraphNode(ObjectGraphNode parent, String path) Create at a sub level.ObjectGraphNode(ObjectGraphOrigin origin, String path) Create an the root level. -
Method Summary
-
Constructor Details
-
ObjectGraphNode
Create at a sub level. -
ObjectGraphNode
Create an the root level.
-
-
Method Details
-
origin
Return the origin query point. -
path
Return the path relative to the root. -
toString
-
hashCode
-
equals
-