Class QueryCacheEntry

java.lang.Object
io.ebean.cache.QueryCacheEntry

public final class QueryCacheEntry extends Object
For query cache entries we additionally hold the dependent tables and timestamp for the query result.

We use the dependent tables and timestamp to validate that tables the query joins to have not been modified since the query cache entry was cached. If any dependent tables have since been modified the query cache entry is treated as invalid.

  • Constructor Details

    • QueryCacheEntry

      public QueryCacheEntry(Object value, Set<String> dependentTables, Instant timestamp)
      Create with dependent tables and timestamp.
      Parameters:
      value - The query result being cached
      dependentTables - The extra tables the query is dependent on (joins to)
      timestamp - The timestamp that the query uses to check for modifications
  • Method Details

    • value

      public Object value()
      Return the actual query result.
    • dependentTables

      public Set<String> dependentTables()
      Return the tables the query result is dependent on.
    • timestamp

      public Instant timestamp()
      Return the timestamp used to check for modifications on the dependent tables.