Class QueryPlanInit

java.lang.Object
io.ebean.meta.QueryPlanInit

public class QueryPlanInit extends Object
Initiate query plan collection for plans by their hash or all query plans.
  • Constructor Summary

    Constructors
    Constructor
    Description
     
  • Method Summary

    Modifier and Type
    Method
    Description
    void
    add(String hash, long thresholdMicros)
    Return the specific hashes that we want to collect query plans on.
    boolean
    Return true if the query plan should be initiated based on it's hash.
    boolean
    Return true if this initiates bind collection on all query plans.
    boolean
    Return true if there are no registered hashes and not collect All plans.
    void
    remove(String hash)
    Remove a hash from this request.
    void
    setAll(boolean all)
    Set to true to initiate bind collection on all query plans.
    long
    Return the default query execution time threshold which must be exceeded to initiate query plan collection.
    void
    thresholdMicros(long thresholdMicros)
    Set the default query execution time threshold which must be exceeded to initiate query plan collection.
    long
    Return the threshold in micros to use for the given hash.
     

    Methods inherited from class Object

    clone, equals, finalize, getClass, hashCode, notify, notifyAll, wait, wait, wait
  • Constructor Details

    • QueryPlanInit

      public QueryPlanInit()
  • Method Details

    • isAll

      public boolean isAll()
      Return true if this initiates bind collection on all query plans.
    • setAll

      public void setAll(boolean all)
      Set to true to initiate bind collection on all query plans.
    • thresholdMicros

      public long thresholdMicros()
      Return the default query execution time threshold which must be exceeded to initiate query plan collection.
    • thresholdMicros

      public void thresholdMicros(long thresholdMicros)
      Set the default query execution time threshold which must be exceeded to initiate query plan collection.
    • includeHash

      public boolean includeHash(String hash)
      Return true if the query plan should be initiated based on it's hash.
    • add

      public void add(String hash, long thresholdMicros)
      Return the specific hashes that we want to collect query plans on.
      Parameters:
      hash - The hash of the query plan.
      thresholdMicros - The threshold in micros to use.
    • remove

      public void remove(String hash)
      Remove a hash from this request.
    • thresholdMicros

      public long thresholdMicros(String hash)
      Return the threshold in micros to use for the given hash.
    • isEmpty

      public boolean isEmpty()
      Return true if there are no registered hashes and not collect All plans.
    • toString

      public String toString()
      Overrides:
      toString in class Object