JavaScript is disabled on your browser.
Skip navigation links
Module
Class
Use
Tree
Deprecated
Index
Search
Help
io.ebean.api
io.ebean.plugin
Property
Contents
Description
Method Summary
Method Details
name()
type()
value(Object)
isMany()
Hide sidebar
Show sidebar
Interface Property
All Known Subinterfaces:
PropertyAssocMany
public interface
Property
Property of a entity bean that can be read.
Method Summary
All Methods
Instance Methods
Abstract Methods
Modifier and Type
Method
Description
boolean
isMany
()
Return true if this is a OneToMany or ManyToMany property.
String
name
()
Return the name of the property.
Class
<?>
type
()
Return the type of the property.
Object
value
(
Object
bean)
Return the value of the property on the given bean.
Method Details
name
String
name
()
Return the name of the property.
type
Class
<?>
type
()
Return the type of the property.
value
Object
value
(
Object
bean)
Return the value of the property on the given bean.
isMany
boolean
isMany
()
Return true if this is a OneToMany or ManyToMany property.