Class QueryCacheEntry
java.lang.Object
io.ebean.cache.QueryCacheEntry
For query cache entries we additionally hold the dependent tables and timestamp for the query result.
We use the dependent tables and timestamp to validate that tables the query joins to have not been modified since the query cache entry was cached. If any dependent tables have since been modified the query cache entry is treated as invalid.
-
Constructor Summary
ConstructorsConstructorDescriptionQueryCacheEntry(Object value, Set<String> dependentTables, Instant timestamp) Create with dependent tables and timestamp. -
Method Summary
-
Constructor Details
-
QueryCacheEntry
Create with dependent tables and timestamp.- Parameters:
value- The query result being cacheddependentTables- The extra tables the query is dependent on (joins to)timestamp- The timestamp that the query uses to check for modifications
-
-
Method Details
-
value
Return the actual query result. -
dependentTables
-
timestamp
Return the timestamp used to check for modifications on the dependent tables.
-