Class QueryPlanInit
java.lang.Object
io.ebean.meta.QueryPlanInit
Initiate query plan collection for plans by their hash or all query plans.
-
Constructor Summary
Constructors -
Method Summary
Modifier and TypeMethodDescriptionvoidReturn the specific hashes that we want to collect query plans on.booleanincludeHash(String hash) Return true if the query plan should be initiated based on it's hash.booleanisAll()Return true if this initiates bind collection on all query plans.booleanisEmpty()Return true if there are no registered hashes and not collect All plans.voidRemove a hash from this request.voidsetAll(boolean all) Set to true to initiate bind collection on all query plans.longReturn the default query execution time threshold which must be exceeded to initiate query plan collection.voidthresholdMicros(long thresholdMicros) Set the default query execution time threshold which must be exceeded to initiate query plan collection.longthresholdMicros(String hash) Return the threshold in micros to use for the given hash.toString()
-
Constructor Details
-
QueryPlanInit
public QueryPlanInit()
-
-
Method Details
-
isAll
public boolean isAll()Return true if this initiates bind collection on all query plans. -
setAll
public void setAll(boolean all) Set to true to initiate bind collection on all query plans. -
thresholdMicros
public long thresholdMicros()Return the default query execution time threshold which must be exceeded to initiate query plan collection. -
thresholdMicros
public void thresholdMicros(long thresholdMicros) Set the default query execution time threshold which must be exceeded to initiate query plan collection. -
includeHash
Return true if the query plan should be initiated based on it's hash. -
add
Return the specific hashes that we want to collect query plans on.- Parameters:
hash- The hash of the query plan.thresholdMicros- The threshold in micros to use.
-
remove
Remove a hash from this request. -
thresholdMicros
Return the threshold in micros to use for the given hash. -
isEmpty
public boolean isEmpty()Return true if there are no registered hashes and not collect All plans. -
toString
-